calview : Calendar view — amici1

# `calview` : Calendar view

See also `lino_xl.lib.calview`.

## Models

## Actors

- Planners : (no docstring)

- Planner rows : (no docstring)

- ParameterClone : (no docstring)

- DaysTable : (no docstring)

- DayNavigator : (no docstring)

- CalendarView : (no docstring)

- DaySlave : (no docstring)

- Daily planner : (no docstring)

- Weekly planner : (no docstring)

- Monthly planner : (no docstring)

- Daily planner : (no docstring)

- None : (no docstring)

- None : (no docstring)

- None : (no docstring)

- Daily view : (no docstring)

- Weekly view : (no docstring)

- Monthly view : (no docstring)